@@ -1,5 +1,6 @@
 from PymoNNto.Exploration.Network_UI.TabBase import *
 from PymoNNto.Exploration.StorageManager.StorageManager import *
+from PymoNNto.Exploration.Evolution.PlotQTObjects import *
 
 def pol2cart(theta, rho):
     x = rho * np.cos(theta)
@@ -11,7 +12,7 @@ def cart2pol(x, y):
     rho = np.hypot(x, y)
     return theta, rho
 
-class DrawItem2(pg.GraphicsObject):
+class Radar_Plot_Item(pg.GraphicsObject):
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -74,7 +75,7 @@ class DrawItem2(pg.GraphicsObject):
             qf.setPointSizeF(5.0)
             #qf.setStretch(2)
             painter.setFont(qf)
-            painter.drawText(x,y,char)#+' ('+str(min_a[i])+'-'+str(max_a[i])+')'
+            painter.drawText(int(x),int(y),char)#+' ('+str(min_a[i])+'-'+str(max_a[i])+')'
 
     def draw_genome(self, painter, alphabet, len_alphabet, min_a, max_a, vals):
         positions = []
@@ -146,42 +147,6 @@ class DrawItem2(pg.GraphicsObject):
             painter.setPen(pg.mkPen(color=(0, 0, 0, 255)))
             self.draw_chars(painter, alphabet, data)
 
-
-
-        '''
-        self.groups=groups
-
-        #for group in groups:
-        #    self.initialize_neuron_positons(group)
-
-        for group in nui.network.NeuronGroups:
-            self.compute_and_apply_attraction(group, p1, p2, p3, p4, p5, attractor_rads)
-
-        painter.scale(1, -1)
-
-        for group in groups:
-            self.draw_neurons(painter, group, p0)
-
-        #painter.setBrush(pg.mkBrush(color=(0,255,0,255)))
-        #for x, y in zip(group.buffer_posx+attractor_rad_x, group.buffer_posy+attractor_rad_y):
-        #    painter.drawEllipse(QtCore.QPointF(x, y), 1, 1)
-
-        if show_weights:
-            for group in groups:
-                if group.tags[0] == nui.neuron_select_group:
-                    self.draw_weights(painter, group, nui.neuron_select_id)
-
-
-        painter.setPen(pg.mkPen(color=(0, 0, 0, 255), width=10))
-        painter.setBrush(pg.mkBrush(color=(0, 0, 0, 0)))
-
-        for group in nui.network.NeuronGroups:
-            if hasattr(group, 'Input_Weights'):
-                self.fixate_points(group, alphabet, group.Input_Weights)
-
-        self.draw_chars(painter, alphabet, statistics)
-        '''
-
         painter.end()
         self.prepareGeometryChange()
         self.informViewBoundsChanged()
@@ -199,47 +164,19 @@ class DrawItem2(pg.GraphicsObject):
         return QtCore.QRectF(br)
 
 def add_evolution_plot_items(ui, tab):
-    tab.curves, tab.plot = ui.Add_plot_curve(x_label='generations', y_label='score', number_of_curves=3, return_plot=True, colors=[(0, 0, 0), (0, 0, 0), (0, 0, 0)])
-    tab.item = pg.FillBetweenItem(curve1=tab.curves[1], curve2=tab.curves[2], brush=(255, 0, 0, 100))
-    tab.plot.addItem(tab.item)
-    tab.scatter = pg.ScatterPlotItem(size=10, brush=pg.mkBrush(255, 255, 255, 120))
-    tab.plot.addItem(tab.scatter)
+    tab.interactive_scatter = ui.Add_element(InteractiveScatter('gen', 'score', 'score'))
+
+    def on_item_clicked(sm):
+        data=sm.load_param_list(tab.gene_keys + ['id'] + ['gen', 'score'], return_dict=True)
+        tab.clicked_evo.setText('Clicked genome: ' + str(data))#str(dict(zip(tab.gene_keys + ['id'] + ['gen', 'score'], data)))
+        tab.draw_item.update_pic(tab.gene_keys, tab.data, data['id'], tab.slider.value())
+
+    tab.interactive_scatter.scatter_clicked_event = on_item_clicked
 
-    tab.clicked_generation=-1
-    tab.clicked_score=-1
     tab.clicked_id=-1
 
-    def clicked(plot, points):
-        print('clicked')
-        #for p in points:
-        if len(points) > 0:
-            p = points[-1]
-            tab.clicked_generation = p._data[0]
-            tab.clicked_score = p._data[1]
-            tab.scatter2.setData(x=[tab.clicked_generation],y=[tab.clicked_score])
-
-            if tab.data is not None and tab.gene_keys is not None:
-                tab.clicked_id = np.where((tab.data[-2] == tab.clicked_generation) & (tab.data[-1] == tab.clicked_score))
-                if len(tab.clicked_id) > 0:
-                    tab.clicked_id = tab.clicked_id[0]
-                    if len(tab.clicked_id) > 0:
-                        tab.clicked_id = tab.clicked_id[0]
-                        tab.clicked_evo.setText('Clicked genome: ' + str(dict(zip(tab.gene_keys + ['gen', 'score'], tab.data[:, tab.clicked_id]))))
-
-                        tab.draw_item.update_pic(tab.gene_keys, tab.data, tab.clicked_id, tab.slider.value())
-
-    tab.scatter.sigClicked.connect(clicked)
-
-    tab.scatter2 = pg.ScatterPlotItem(size=10, brush=pg.mkBrush(0, 0, 255, 255))
-    tab.plot.addItem(tab.scatter2)
-
-    #g = pg.GraphItem()
-    #tab.plot.addItem(g)
-    # Update the graph
-    #g.setData(pos=np.array([[100, 100]]), pen=['r'], brush=['r'], size=10, symbol=['o'], pxMode=False)
-
-    tab.radar_plot = ui.Add_plot(x_label='radar plot', tooltip_message='radar plot of the last 100 genomes. (green=high score/red=low score/blue=selected)')  # axisItems={'left': stringaxis}
-    tab.draw_item = DrawItem2()
+    tab.radar_plot = ui.Add_plot(x_label='radar plot', tooltip_message='radar plot of the last genomes. (green=high score/red=low score/blue=selected)')  # axisItems={'left': stringaxis}
+    tab.draw_item = Radar_Plot_Item()
     tab.radar_plot.addItem(tab.draw_item)
 
     def val_changed():
@@ -255,14 +192,11 @@ def add_evolution_plot_items(ui, tab):
     tab.radar_plot.hideAxis('bottom')
     tab.radar_plot.hideAxis('left')
     tab.draw_item.update_pic([], None, None, tab.slider.value())
-    #tab.draw_item.mouseClickEvent = c
 
-
-
-    ui.Next_H_Block(stretch=0.0)
+    ui.Next_H_Block(stretch=0)
     tab.best_evo = ui.Add_element(QLineEdit('...'), stretch=0)
 
-    ui.Next_H_Block(stretch=0.0)
+    ui.Next_H_Block(stretch=0)
     tab.clicked_evo = ui.Add_element(QLineEdit('...'), stretch=0)
 
 
@@ -270,41 +204,24 @@ def add_evolution_plot_items(ui, tab):
 def update_evolution_plot(ui, tab, evo_name, gene_keys, data_folder=get_data_folder()):
     print(len(next(os.walk(data_folder + '/StorageManager/'+evo_name))[1]), 'datapoints found')
 
-    smg = StorageManagerGroup(evo_name, data_folder=data_folder)
+    tab.smg = StorageManagerGroup(evo_name, data_folder=data_folder)
 
-    smg.sort_by('gen')
+    tab.interactive_scatter.add_StorageManagerGroup(tab.smg)
+    tab.interactive_scatter.refresh_data()
+
+    tab.smg.sort_by('score')#gen
 
     tab.gene_keys = gene_keys
 
-    result_lists = smg.get_multi_param_list(gene_keys+['gen', 'score'], remove_None=True)
-
-    xa, ya = smg.remove_duplicates_get_eval(result_lists[-2], result_lists[-1], evalstr='np.average(a)')
-    xs, ymi = smg.remove_duplicates_get_eval(result_lists[-2], result_lists[-1], evalstr='np.min(a)')
-    xs, yma = smg.remove_duplicates_get_eval(result_lists[-2], result_lists[-1], evalstr='np.max(a)')
-
-    tab.curves[0].setData(xa, ya)
-    tab.curves[1].setData(xa, ymi)
-    tab.curves[2].setData(xa, yma)
-
-    tab.scatter.setData(x=result_lists[-2], y=result_lists[-1])
+    result_lists = tab.smg.get_multi_param_list(gene_keys+['id']+['gen', 'score'], remove_None=True).astype(np.float64)
 
     tab.data = np.array(result_lists)
 
-    tab.best_evo.setText('Best genome: ' + str(dict(zip(gene_keys+['gen', 'score'], tab.data[:, -1]))))
+    tab.best_evo.setText('Best genome: ' + str(dict(zip(gene_keys+['id']+['gen', 'score'], tab.data[:, -1]))))
 
     tab.draw_item.update_pic(gene_keys, tab.data, tab.clicked_id, tab.slider.value())
 
     tab.radar_plot.update()
 
-#def c(event):
-#    for group in event.currentItem.groups:
-#        dx = group.buffer_posx - event.pos().x()
-#        dy = group.buffer_posy - event.pos().y() * -1
-#        d = np.sqrt(dx * dx + dy * dy)
 
-#        indices = np.where(d < 1)[0]
-
-        #if len(indices) > 0:
-        #    Network_UI.neuron_select_group = group.tags[0]
-        #    Network_UI.neuron_select_id = indices[0]
 
