@@ -14,6 +14,7 @@ from PymoNNto.Exploration.Network_UI.Basic_Tabs.individual_weight_tab import *
 from PymoNNto.Exploration.Network_UI.Basic_Tabs.PCA_tab import *
 from PymoNNto.Exploration.Network_UI.Basic_Tabs.isi_tab import *
 from PymoNNto.Exploration.Network_UI.Basic_Tabs.code_execution_tab import *
+from PymoNNto.Exploration.Network_UI.Basic_Tabs.classifier_bar_tab import *
 from PymoNNto.Exploration.Network_UI.Basic_Tabs.module_visualizer_tab import *
 
 from PymoNNto.Exploration.Network_UI.Basic_Tabs.sidebar_neuron_grid import *
@@ -43,6 +44,7 @@ def get_default_UI_modules(neuron_parameters=['output'], synapse_parameters=['W'
     sidebar_fast_forward_module(),
     sidebar_save_load_module(),
     code_execution_tab(),
+    classifier_bar_tab(),
     event_tab(),
     #module_visualizer_tab()
     sidebar_module_quick_access(quick_access_tags)
@@ -52,16 +54,17 @@ def get_modules_dict(*args): #get_modules_dict([m1,m2,m3],m4,[m5],{1:m6,2:m7},..
     result = {}
 
     for arg in args:
-        if type(arg) is list:
-            for a in arg:
-                result[a.__class__] = a
+        if arg is not None:
+            if type(arg) is list:
+                for a in arg:
+                    result[a.__class__] = a
 
-        elif type(arg) is dict:
-            for k in arg:
-                result[arg[k].__class__] = arg[k]
+            elif type(arg) is dict:
+                for k in arg:
+                    result[arg[k].__class__] = arg[k]
 
-        else:
-            result[arg.__class__] = arg
+            else:
+                result[arg.__class__] = arg
 
 
     #for module in modules:
