@@ -14,12 +14,15 @@ class sidebar_fast_forward_module(TabBase):
         for rec in Network_UI.network['UI_rec']:
             rec.behaviour_enabled = enable or self.rec_cb.isChecked()
 
-    def update_progress(self, progress):
+    def update_progress(self, progress, network=None):
         #self.progressbar.setHidden(False)
         QApplication.instance().processEvents()
-        self.progressbar.setValue(progress)
+        self.progressbar.setValue(int(progress))
 
     def fast_forward(self, steps, Network_UI):
+
+        Network_UI.add_event('fast forward', steps)
+
         self.update_progress(0)
         Network_UI.timer.stop()
         self.recorder_on_off(Network_UI, False)
