@@ -87,8 +87,12 @@ class Network_UI(UI_Base):
         if type(self.modules) is dict:
             self.modules = self.modules.values()
 
+        for beh in network.all_behaviours():
+            for module in beh.get_UI_Tabs():
+                self.modules.append(module)
+
         for module in self.modules:
-            print('Initialize:', module)
+            print('Initialize:', type(module).__name__)
             module.initialize(self)
 
         for group_tag in group_tags:
@@ -147,6 +151,9 @@ class Network_UI(UI_Base):
     def selected_neuron_id(self):
         return self._neuron_select_mask.argmax()#first "True" value in array
 
+    def selected_neuron_ids(self):
+        return np.where(self._neuron_select_mask)[0]
+
 
 
     def add_recording_variable(self, group, var, timesteps):
