@@ -1,3 +1,4 @@
+from PymoNNto.Exploration.Network_UI.Network_UI import *
 from PymoNNto.Exploration.Network_UI.TabBase import *
 
 def pol2cart(theta, rho):
@@ -16,6 +17,12 @@ class DrawItem2(pg.GraphicsObject):
         super().__init__(parent)
         self.picture = QtGui.QPicture()
 
+        self._stored_similarity_colors=None
+        self._last_selected_neuron=-1
+        self._stored_class_colors=None
+        self._last_sensitivity=-1
+
+
     #base_char_masks_dict
 
     def draw_rings(self, painter, alphabet, num_rings):
@@ -34,7 +41,7 @@ class DrawItem2(pg.GraphicsObject):
                 x, y = pol2cart(d / len(alphabet) * 2 * np.pi, r)
                 painter.setBrush(pg.mkBrush(color=(c, c, c, 255)))
                 painter.drawEllipse(QtCore.QPointF(x, y), 1, 1)
-        return  attractor_rads
+        return attractor_rads
 
     def compute_and_apply_attraction(self, group, attractor_rads):
 
@@ -113,22 +120,78 @@ class DrawItem2(pg.GraphicsObject):
         group.buffer_posx = np.clip(group.buffer_posx + group.add_x * movement_speed_fac, -100, +100)
         group.buffer_posy = np.clip(group.buffer_posy + group.add_y * movement_speed_fac, -100, +100)
 
+    def similarity_to_color(self, group, similarity):
+        result = []
+        for s in similarity:
+            color=(group.color[0],group.color[1],group.color[2],(1-s)*255)
+            result.append(color)
+        return result
+
+    #def class_to_color(self, classes):
+    #    result = []
+    #    class_colors = {}
+    #    for c in classes:
+    #        if c not in class_colors:
+    #            class_colors[c]=(np.random.rand()*255,np.random.rand()*255,np.random.rand()*255,255)
+    #        result.append(class_colors[c])
+    #    return result
 
 
+    def get_neuron_color(self, group):
 
-    def draw_neurons(self, painter, group, neuron_size=1):
-        painter.setPen(pg.mkPen(color=group.color))
-        painter.setBrush(pg.mkBrush(color=group.color))
-        mask=group.output>0
-        inv_mask=np.invert(mask)
-        for x, y in zip(group.buffer_posx[inv_mask], group.buffer_posy[inv_mask]):
-            painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
+        if hasattr(group, 'classification'):
+            colors = np.array(group['Neuron_Classification_Colorizer', 0].get_color_list(group.classification, format='[r,g,b]'))
+
+        #classification = self.cb.get_selected_result()
+        #colors = np.array(group['Neuron_Classification_Colorizer', 0].get_color_list(classification, format='[r,g,b]'))
+
+        return colors
+
+
+    def draw_neurons(self, painter, group, neuron_size=1, selected_neurons=None):
+
+        color = self.get_neuron_color(group)
+
+        painter.setPen(0)
+
+        inactive = group.output <= 0
+        active = np.invert(inactive)
+
+        for c in unique(color, axis=0):
+            mask = np.all(color == c[None,:], axis=1) * inactive #(color == c) np.all(a == b, axis=1)
+            painter.setBrush(pg.mkBrush(color=c))
+            for x, y in zip(group.buffer_posx[mask], group.buffer_posy[mask]):
+                painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
 
-        painter.setPen(pg.mkPen(color=(0,255,0,150)))
         painter.setBrush(pg.mkBrush(color=(0,255,0,150)))
-        for x, y in zip(group.buffer_posx[mask], group.buffer_posy[mask]):
+        for x, y in zip(group.buffer_posx[active], group.buffer_posy[active]):
             painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
 
+        if selected_neurons is not None:
+            painter.setBrush(pg.mkBrush(color=(0, 255, 0, 255)))
+            for x, y in zip(group.buffer_posx[selected_neurons], group.buffer_posy[selected_neurons]):
+                painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
+
+        #if type(color) is tuple:
+        #painter.setBrush(pg.mkBrush(color=group.color))
+        #mask=group.output>0
+        #inv_mask=np.invert(mask)
+        #for i, p in enumerate(zip(group.buffer_posx, group.buffer_posy)):#[inv_mask]
+        #    x, y=p
+        #    if type(color) is list or type(color) is np.ndarray:
+        #        if group.output[i] <= 0:
+                    #painter.setPen(0)#pg.mkPen(color=color[i])
+        #            painter.setBrush(pg.mkBrush(color=color[i]))
+        #        else:
+        #            #painter.setPen(0)#pg.mkPen(color=(0,255,0,150))
+        #            painter.setBrush(pg.mkBrush(color=(0,255,0,150)))
+        #    painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
+
+        #painter.setPen(pg.mkPen(color=(0,255,0,150)))
+        #painter.setBrush(pg.mkBrush(color=(0,255,0,150)))
+        #for x, y in zip(group.buffer_posx[mask], group.buffer_posy[mask]):
+        #    painter.drawEllipse(QtCore.QPointF(x, y), neuron_size, neuron_size)
+
     def draw_weights(self, painter, group, selected_neuron_id):
         painter.setPen(pg.mkPen(color=(255, 0, 0, 255)))
         painter.setBrush(pg.mkBrush(color=(0, 0, 0, 0)))
@@ -175,15 +238,68 @@ class DrawItem2(pg.GraphicsObject):
                 c='_'
             else:
                 c=char
-            painter.drawText(x,y,c)
+            painter.drawText(int(x),int(y),c)
 
-    def attach_parameter_slider(self, p0s, p1s, p2s, p3s, p4s, p5s):
+    def attach_parameter_slider(self, p0s, p1s, p2s, p3s, p4s, p5s, label_cb):
         self.p0s = p0s
         self.p1s = p1s
         self.p2s = p2s
         self.p3s = p3s
         self.p4s = p4s
         self.p5s = p5s
+        self.label_cb = label_cb
+
+    #def compute_similarity(self, group, neuron_index):
+    #    group._syn_differences_ = group.get_neuron_vec()
+    #    for sg in group.afferent_synapses['GLU']:
+    #        if neuron_index in sg.dst.id:
+    #            sg.dst._syn_differences_ += np.sum(sg.W * sg.W[:,np.where(sg.dst.id==neuron_index)[0]], axis=1)
+
+    #    m=np.max(group._syn_differences_)
+    #    if m>0:
+    #        group._syn_differences_=1.0-(group._syn_differences_/m)
+
+        #print(group._syn_differences_)
+
+    #    return group.get_neuron_vec('uniform')#group._syn_differences_
+
+    def draw_labels(self, painter, group, selection):
+
+        #group = self.label_cb.main_object
+        if group==self.label_cb.main_object and selection is not None:
+
+            if hasattr(group, 'classification'):
+                tag = self.label_cb.get_selected_key()
+                module = self.label_cb.get_selected_module()
+                res = self.label_cb.get_selected_result()
+                generator = group.network['Text_Generator', 0]
+                colors = self.get_neuron_color(group)
+
+                if tag in self.label_cb.current_modules and module is not None and generator is not None:
+                    for i in range(len(selection)):
+                        if selection[i]>0:
+                            #painter.setPen(pg.mkPen(color=())))
+
+                            qf = QFont('Consolas')
+                            qf.setPointSizeF(1.0)
+                            painter.setFont(qf)
+                            painter.drawText(int(group.buffer_posx[i]), int(group.buffer_posy[i]), res[i])
+
+
+                    #class_tag_dict = module.get_class_labels(tag, group.classification, generator)
+
+                    #for c in class_tag_dict:
+                    #    mask = group.classification == c
+                    #    x = np.mean(group.buffer_posx[mask])
+                    #    y = np.mean(group.buffer_posy[mask])
+
+                    #    painter.setPen(pg.mkPen(color=colors[mask][0]))
+
+                    #    qf = QFont('Consolas')
+                    #    qf.setPointSizeF(1.0)
+                    #    painter.setFont(qf)
+                    #    painter.drawText(x, y, class_tag_dict[c])
+
 
 
     def update_pic(self, groups, alphabet, nui, statistics, show_weights):
@@ -193,7 +309,12 @@ class DrawItem2(pg.GraphicsObject):
 
         attractor_rads=self.draw_rings(painter,alphabet,10)
 
-        self.groups=groups
+        self.groups = groups
+
+        for group in nui.network.NeuronGroups:
+            if hasattr(group, 'Input_Weights'):
+                self.fixate_points(group, alphabet, group.Input_Weights)
+            #self.fixate_points(group, alphabet, group['Text_Activator',0].mat)
 
         #for group in groups:
         #    self.initialize_neuron_positons(group)
@@ -204,29 +325,34 @@ class DrawItem2(pg.GraphicsObject):
         painter.scale(1, -1)
 
         for group in groups:
-            self.draw_neurons(painter, group, self.p0s.sliderPosition() / 100)
+            if group == nui.selected_neuron_group():
+                sel = nui.selected_neuron_mask()
+            else:
+                sel = None
+            self.draw_neurons(painter, group, self.p0s.sliderPosition() / 100, sel)
 
         #painter.setBrush(pg.mkBrush(color=(0,255,0,255)))
         #for x, y in zip(group.buffer_posx+attractor_rad_x, group.buffer_posy+attractor_rad_y):
         #    painter.drawEllipse(QtCore.QPointF(x, y), 1, 1)
 
         if show_weights:
-            for group in groups:
-                if group.tags[0] == nui.neuron_select_group:
-                    self.draw_weights(painter, group, nui.neuron_select_id)
+            self.draw_weights(painter, nui.selected_neuron_group(), nui.selected_neuron_id())
 
 
         painter.setPen(pg.mkPen(color=(0, 0, 0, 255), width=10))
         painter.setBrush(pg.mkBrush(color=(0, 0, 0, 0)))
 
-        for group in nui.network.NeuronGroups:
-            if hasattr(group, 'Input_Weights'):
-                self.fixate_points(group, alphabet, group.Input_Weights)
-            #self.fixate_points(group, alphabet, group['Text_Activator',0].mat)
-
 
         self.draw_chars(painter, alphabet, statistics)
 
+        #for group in nui.network.NeuronGroups:
+        for group in groups:
+            if group == nui.selected_neuron_group():
+                sel = nui.selected_neuron_mask()
+            else:
+                sel = None
+            self.draw_labels(painter, group, sel)
+
         painter.end()
         self.prepareGeometryChange()
         self.informViewBoundsChanged()
@@ -251,9 +377,12 @@ class sun_gravity_plot_tab(TabBase):
     def add_recorder_variables(self, neuron_group, Network_UI):
         return
 
+    #def on_selected_neuron_changed(self, Network_UI):
+    #    self.comboBox.change_main_object(Network_UI.get_selected_neuron_group())
+
     def initialize(self, Network_UI):
         self.sun_gravity_plot_tab=None
-        if Network_UI.network['text_generator', 0] is not None or Network_UI.network['grammar_act', 0] is not None or Network_UI.network['drum_act', 0] is not None or Network_UI.network['music_act', 0] is not None:
+        if Network_UI.network['Text_Generator', 0]:# is not None or Network_UI.network['grammar_act', 0] is not None or Network_UI.network['drum_act', 0] is not None or Network_UI.network['music_act', 0] is not None:
             self.sun_gravity_plot_tab = Network_UI.Next_Tab(self.title)
 
             #alphabet = Network_UI.network['grammar_act'][0].alphabet
@@ -268,17 +397,30 @@ class sun_gravity_plot_tab(TabBase):
             for group in Network_UI.network.NeuronGroups:
                 group.buffer_posx, group.buffer_posy = pol2cart(group.get_neuron_vec('uniform') * 2 * np.pi, group.get_neuron_vec('uniform') * 100)
 
-            def c(event):
+            self.last_id = -1
+            self.last_group = -1
+
+            def mdce(event):
+                if self.last_group.classification is not None:
+                    selected_class = self.last_group.classification[self.last_id]
+                    Network_UI.select_neuron_class(self.last_group, selected_class)
+
+            def mce(event):
+                sel_index=0
+                min_dist=-1
+                self.last_group = None
                 for group in event.currentItem.groups:
                     dx = group.buffer_posx-event.pos().x()
                     dy = group.buffer_posy-event.pos().y() * -1
                     d = np.sqrt(dx*dx+dy*dy)
+                    if min_dist==-1 or np.min(d)<min_dist:
+                        min_dist = np.min(d)
+                        sel_index = np.argmin(d)
+                        self.last_group = group
+                self.last_id = sel_index
+                Network_UI.select_neuron(self.last_group, sel_index)
 
-                    indices = np.where(d<1)[0]
 
-                    if len(indices) > 0:
-                        Network_UI.neuron_select_group = group.tags[0]
-                        Network_UI.neuron_select_id = indices[0]
 
             msg = 'Each particle is a neuron of the selected Group.\r\n' \
                   'The primary input neurons are fixed to the outer ring.\r\n' \
@@ -288,33 +430,29 @@ class sun_gravity_plot_tab(TabBase):
                   'but the particlses position moved one step furter to the center, so one ring indicates one iteration step.'
 
             self.plot = Network_UI.Add_plot(x_label='buffer steps', tooltip_message=msg)#axisItems={'left': stringaxis}
+            self.plot.hideAxis('bottom')
+            self.plot.hideAxis('left')
+
             self.draw_item = DrawItem2()
             self.plot.addItem(self.draw_item)
-            self.draw_item.mouseClickEvent = c
+            self.draw_item.mouseClickEvent = mce
+            self.draw_item.mouseDoubleClickEvent = mdce
 
-            if Network_UI.network['grammar_act', 0] is not None: 
-                source = Network_UI.network['grammar_act'][0]
-                self.base_char_masks_dict = dict([(char, source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+            #if Network_UI.network['grammar_act', 0] is not None:
+            #    source = Network_UI.network['grammar_act'][0]
+            #    self.base_char_masks_dict = dict([(char, source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
 
-            elif Network_UI.network['drum_act', 0] is not None: 
-                source = Network_UI.network['drum_act'][0]
-                self.base_char_masks_dict = dict([(source.instruments[char], source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+            #elif Network_UI.network['drum_act', 0] is not None:
+            #    source = Network_UI.network['drum_act'][0]
+            #    self.base_char_masks_dict = dict([(source.instruments[char], source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
             
-            elif Network_UI.network['music_act', 0] is not None: 
-                source = Network_UI.network['music_act'][0]
-                self.base_char_masks_dict = dict([(source.midi_index_to_notestring(char), source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+            #elif Network_UI.network['music_act', 0] is not None:
+            #    source = Network_UI.network['music_act'][0]
+            #    self.base_char_masks_dict = dict([(source.midi_index_to_notestring(char), source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
             
 
             Network_UI.Next_H_Block()
 
-            self.sl0 = QSlider(1)
-            self.sl0.setMinimum(0)
-            self.sl0.setMaximum(100)
-            self.sl0.setSliderPosition(50)
-            self.sl0.label = QLabel('Size:')
-            Network_UI.Add_element(self.sl0.label)
-            Network_UI.Add_element(self.sl0, stretch=10)
-
             self.sl1 = QSlider(1)
             self.sl1.setMinimum(0)
             self.sl1.setMaximum(1000)
@@ -355,12 +493,26 @@ class sun_gravity_plot_tab(TabBase):
             Network_UI.Add_element(self.sl5.label)
             Network_UI.Add_element(self.sl5, stretch=10)
 
+
+
+            Network_UI.Next_H_Block()
+
+            self.sl0 = QSlider(1)
+            self.sl0.setMinimum(0)
+            self.sl0.setMaximum(100)
+            self.sl0.setSliderPosition(50)
+            self.sl0.label = QLabel('Size:')
+            Network_UI.Add_element(self.sl0.label)
+            Network_UI.Add_element(self.sl0, stretch=10)
+
             self.weight_plot_cb = QCheckBox()
             self.weight_plot_cb.setText('Show weights')
             self.weight_plot_cb.setChecked(True)
             Network_UI.Add_element(self.weight_plot_cb, stretch=10)
 
-            self.draw_item.attach_parameter_slider(self.sl0, self.sl1, self.sl2, self.sl3, self.sl4, self.sl5)
+            self.comboBox = Network_UI.Add_element(Analytics_Results_Select_ComboBox(Network_UI.network.NeuronGroups[0], tag='labeler', first_entry='none'), stretch=10)
+
+            self.draw_item.attach_parameter_slider(self.sl0, self.sl1, self.sl2, self.sl3, self.sl4, self.sl5, self.comboBox)
 
 
 
@@ -370,6 +522,11 @@ class sun_gravity_plot_tab(TabBase):
 
         if self.sun_gravity_plot_tab is not None and self.sun_gravity_plot_tab.isVisible():
 
+            if Network_UI.network['Text_Generator', 0] is not None:
+                self.draw_item.update_pic(groups, Network_UI.network['Text_Generator', 0].alphabet, Network_UI, Network_UI.network['Text_Generator', 0].count_chars_in_blocks(), self.weight_plot_cb.isChecked())
+                self.plot.update()
+
+            '''
             if Network_UI.network['grammar_act', 0] is not None:
                 #group = Network_UI.network['prediction_source', 0]
 
@@ -395,6 +552,7 @@ class sun_gravity_plot_tab(TabBase):
                 self.draw_item.update_pic(groups, alphabet, Network_UI, source.get_note_input_statistics_list(), self.weight_plot_cb.isChecked())
                 self.plot.update()
 
-            elif Network_UI.network['text_generator', 0] is not None:
-                self.draw_item.update_pic(groups, Network_UI.network['text_generator', 0].alphabet, Network_UI, Network_UI.network['text_generator', 0].count_chars_in_blocks(), self.weight_plot_cb.isChecked())
-                self.plot.update()
+            elif
+            '''
+
+
