@@ -8,15 +8,26 @@ import copy
 class SynapseGroup(NetworkObjectBase):
 
     def __init__(self, src, dst, net, tag=None, behaviour={}):
+
+        if type(src) is str:
+            src = net[src, 0]
+
+        if type(dst) is str:
+            dst = net[dst, 0]
+
+        if tag is None and net is not None:
+            tag = 'SynapseGroup_'+str(len(net.SynapseGroups)+1)
+
         super().__init__(tag=tag)
         self.add_tag('syn')
 
-        if len(src.tags)>0 and len(dst.tags)>0:
+        if len(src.tags) > 0 and len(dst.tags) > 0:
             self.add_tag(src.tags[0]+' => '+dst.tags[0])
 
         if net is not None:
             net.SynapseGroups.append(self)
             self.network = net
+            setattr(net, self.tags[0], self)
 
         self.recording = True
 
@@ -31,7 +42,6 @@ class SynapseGroup(NetworkObjectBase):
             if self.behaviour[k].set_variables_on_init:
                 self.behaviour[k].set_variables(self)
 
-
     def find_objects(self, key):
         result = []
 
@@ -42,6 +52,9 @@ class SynapseGroup(NetworkObjectBase):
             behaviour = self.behaviour[bk]
             result += behaviour[key]
 
+        for am in self.analysis_modules:
+            result += am[key]
+
         return result
 
     '''
